<template>
  <section class="DialogContainerMain">
    <el-dialog title="钱包提现" v-model="state.isShowDialog" width="720px" :close-on-click-modal="false" draggable
      destroy-on-close @close="onCancel">
      <el-form :inline="true" ref="formRef" :model="form" class="demo-form-inline" size="default" label-position="right"
        label-width="200px" :rules="rules">
        <el-row>
          <el-col :span="24">
            <el-form-item label="到账日期" prop="intoAcctDateType">
              <el-radio-group v-model="form.intoAcctDateType" size="small">
                <!-- <el-tooltip class="box-item" effect="dark" content="当日提现，当日可到账，需要扣除手续费0.02%！" placement="top">
                  <el-radio label="D0" size="default" border>当日到账</el-radio>
                </el-tooltip> -->
                <el-tooltip class="box-item" effect="dark" content="当日提现，明日到账，不扣除手续费！" placement="top">
                  <el-radio label="D1" size="default" border>明日到账</el-radio>
                </el-tooltip>
                <!-- <el-tooltip class="box-item" effect="dark" content="次工作日到账！" placement="top">
                  <el-radio label="T1" size="default" border>次工作日到账</el-radio>
                </el-tooltip> -->
              </el-radio-group>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="提现金额" prop="amount">
              <el-input-number v-model="form.amount" :precision="2"></el-input-number>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="联系人手机号" prop="contactPhone">
              <el-input v-model="form.contactPhone" placeholder="" disabled clearable />
              <span class="codebtn">
                <el-button type="primary" @click="send" v-if="!sms.disabled">获取验证码</el-button>
                <el-button type="default" v-else><span style="color:#ccc;">{{ sms.count }} 秒后重新发送</span></el-button>
              </span>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="短信验证码" prop="activeCode">
              <el-input v-model="form.activeCode" placeholder="" clearable />
            </el-form-item>
          </el-col>
          <el-col :span="24" style="text-align: center;">
            <el-form-item>
              <el-button type="primary" @click="submitForm(formRef)">立即提现</el-button>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </el-dialog>
  </section>
</template>
<script setup lang="ts">
import { reactive, nextTick, ref } from 'vue';
import { ElMessage, type FormInstance } from 'element-plus'
import { ConfigApi } from '/@/api/api'

// 定义子组件向父组件传值/事件
const emit = defineEmits(['refresh']);

// 定义变量
const state = reactive({
  isShowDialog: false,
})
const form = reactive({
  walletAccountNo: '',
  intoAcctDateType: '',
  amount: '',
  contactPhone: '',
  activeCode: ''
})
const formRef = ref<FormInstance>()
//必填校验
const validateRadio = (rule: any, value: number, callback: (arg0: Error | undefined) => void) => {
  if (value) {
    if (value == 0) {
      callback(new Error("必填项"));
    } else {
      callback();
    }
  } else {
    callback(new Error("必填项"));
  }
}
//必填校验
const checkPhone = (rule, value, callback) => {
  if (value) {
    if (!(/^1[3456789]\d{9}$/.test(value))) {
      callback(new Error('手机号格式不正确'))
    } else {
      callback()// 注意这里要回调一下，不然提交不了
    }
  } else {
    callback()
  }
}
const rules = reactive({
  intoAcctDateType: [{ required: true, trigger: 'blur', validator: validateRadio }],
  amount: [{ required: true, trigger: 'blur', message: '必填项' }],
  contactPhone: [{ required: true, trigger: 'blur', message: '必填项' }, { required: true, trigger: 'blur', validator: checkPhone }],
  activeCode: [{ required: true, trigger: 'blur', message: '必填项' }],
})
//发送验证码
const send = () => {
  // 计时器处理器
  if (!form.contactPhone) {
    ElMessage({ message: '请输入联系人手机号', type: 'error' })
    return
  }
  if (!(/^1[3456789]\d{9}$/.test(form.contactPhone))) {
    ElMessage({ message: '手机号格式不正确', type: 'error' })
    return
  }
  // 计时器处理器
  timerHandler()
  sendAcode()//发送验证码接口
}
// 验证码计时器
const sms = reactive({
  disabled: false,
  total: 60,
  count: 0
})
// 计时器处理器
const timerHandler = () => {
  sms.count = sms.total
  sms.disabled = true
  let timer = setInterval(() => {
    if (sms.count > 1 && sms.count <= sms.total) {
      sms.count--
    } else {
      clearInterval(timer)
      sms.disabled = false
    }
  }, 1000)
}
//发送验证码接口
const sendAcode = () => {
  let data = {
    phone: form.contactPhone
  }
  ConfigApi().sendAcodeApi(data).then(res => { })
}
// 取消
const onCancel = () => {
  closeDialog();
  emit('refresh')
};
// 关闭弹窗
const closeDialog = () => {
  state.isShowDialog = false;
  nextTick(() => {
    formRef.value?.resetFields();//清空表单，此项需加表单验证才能使用--关闭窗口重重输入框值
  });
};
// 打开弹窗
const openDialog = (walletAccountNo: string, contactPhone: string) => {
  state.isShowDialog = true;
  form.walletAccountNo = walletAccountNo
  form.contactPhone = contactPhone
}
//提交按钮
const submitForm = (formEl: FormInstance | undefined) => {
  console.log('form', form)
  if (!formEl) return
  formEl.validate((valid) => {
    if (valid) {
      console.log('submit!')
      ConfigApi().accountExtractApi(form).then(res => {
        console.log(res)
        if (res.code == 200) {
          ElMessage.success('操作成功')
          onCancel()
        }
      })
    } else {
      console.log('error submit!')
      return false
    }
  })
}
// 暴露变量
defineExpose({
  openDialog,
});
</script>
<style lang="scss" scoped>
.DialogContainerMain {
  .tipsRedColor {
    color: red;
    font-style: normal;
  }

  .el-form-item__content {
    .el-input {
      flex: 1
    }

    .codebtn {
      margin-left: 10px;
    }
  }
}

:deep(.el-input__wrapper) {
  position: relative;

  .el-input__inner {
    padding-right: 18px;
  }

  .el-input__suffix {
    position: absolute;
    right: 8px;
    top: 50%;
    transform: translateY(-50%);
  }
}
</style>